Module: Minitest::HashDiffAssertions
- Defined in:
- lib/minitest/hashdiff.rb
Overview
Prepended so assert_equal failures on two hashes show the readable report instead of the default diff.
Prepended so assert_equal failures on two hashes show the readable report instead of the default diff.